Learn R Programming

rpf (version 1.0.7)

expandDataFrame: Expand summary table of patterns and frequencies

Description

Expand a summary table of unique response patterns to a full sized data-set.

Usage

expandDataFrame(tabdata, freqName = NULL)

Arguments

tabdata

An object of class data.frame with the unique response patterns and the number of frequencies

freqName

Column name containing the frequencies

Value

Returns a data frame with all the response patterns

Examples

Run this code
# NOT RUN {
data(LSAT7)
expandDataFrame(LSAT7, freqName="freq")
# }

Run the code above in your browser using DataLab