powered by
Expand a summary table of unique response patterns to a full sized data-set.
expandDataFrame(tabdata, freqName = NULL)
An object of class data.frame with the unique response patterns and the number of frequencies
data.frame
Column name containing the frequencies
Returns a data frame with all the response patterns
# NOT RUN { data(LSAT7) expandDataFrame(LSAT7, freqName="freq") # }
Run the code above in your browser using DataLab