Convert factor thresholds to response function intercepts
fromFactorThreshold(threshold, loading, ogive = rpf.ogive)a matrix with items in the columns and thresholds in the rows
a matrix with items in the rows and factors in the columns
the ogive constant (default rpf.ogive)
an item intercept matrix with items in the columns and intercepts in the rows
Other factor model equivalence:
fromFactorLoading(),
toFactorLoading(),
toFactorThreshold()