Learn R Programming

rpf (version 0.18)

rpf.drm: Create a dichotomous response model

Description

For slope vector a, intercept c, pseudo-guessing parameter g, upper bound u, and latent ability vector theta, the response probability function is $$\mathrm P(\mathrm{pick}=0|a,c,g,u,\theta) = 1- \mathrm P(\mathrm{pick}=1|a,c,g,u,\theta)$$ $$\mathrm P(\mathrm{pick}=1|a,c,g,u,\theta) = g+(u-g)\frac{1}{1+\exp(-(a\theta + c))}$$

Usage

rpf.drm(factors = 1, multidimensional = TRUE,
    poor = FALSE)

Arguments

factors
the number of factors
multidimensional
whether to use a multidimensional model. Defaults to TRUE.
poor
if TRUE, use the traditional parameterization of the 1d model instead of the slope-intercept parameterization

Value

  • an item model

Details

For discussion on the choice of priors see Cai, Yang, and Hansen (2011, p. 246).

References

Cai, L., Yang, J. S., & Hansen, M. (2011). Generalized Full-Information Item Bifactor Analysis. Psychological Methods, 16(3), 221-248.