Learn R Programming

rpf (version 0.16)

rpf.nrm: Create a nominal response model

Description

This function instantiates a nominal response model. The T matrix must be an invertible square matrix of dimension outcomes-1. As a shortcut, either T matrix can be specified as "trend" for a Fourier basis or as "id" for an identity basis.

Usage

rpf.nrm(outcomes = 3, factors = 1, T.a = "trend",
    T.c = "trend")

Arguments

outcomes
The number of choices available
factors
the number of factors
T.a
the T matrix for slope parameters
T.c
the T matrix for intercept parameters

Value

  • an item model

References

Thissen, D., Cai, L., & Bock, R. D. (2010). The Nominal Categories Item Response Model. In M. L. Nering & R. Ostini (Eds.), Handbook of Polytomous Item Response Theory Models (pp. 43--75). Routledge.

Examples

Run this code
# typical parameterization for the Generalized Partial Credit Model
gpcm <- function(outcomes) rpf.nrm(outcomes, T.c=lower.tri(diag(outcomes-1),TRUE) * -1)

Run the code above in your browser using DataLab